[Web app](http://ulfaslak.com/works/network_styling_with_d3/index.html) for styling networks with buttons and sliders, powered by [d3-force](https://github.com/d3/d3-force).

<p align="center"><img src="http://ulfaslak.com/files/network_webapp_teaser.png" width=600></p>

### Scenario
You need to visualize a network and show it to people. The easy solution is to use `networkx`, which at best looks like a nightmare. Instead you go through the trouble of throwing your data into your [favorite d3 boilerplate example](https://bl.ocks.org/mbostock/ad70335eeef6d167bc36fd3c04378048), play with the simulation parameters and screenshot the network when it looks nice. The difference is remarkable: 

![networkx_vs_d3](http://ulfaslak.com/files/ugly_not_ugly.png)

Your audience will applaud your design skills and ask you how you make your figures over drinks that they payed for.
